@@ -494,10 +494,10 @@ sub set_io {
 			my $name = $track->name;
 			my $width = scalar @{ Audio::Nama::jack_client_array($id, $client_direction) };
 			$width or Audio::Nama::pager(
-				qq($name: $direction port for JACK client "$id" not found.));
+				qq(Track $name: $direction port for JACK client "$id" not found.));
 			$width or return;
 			$width ne $track->width and Audio::Nama::pager(
-				$track->name, ": track set to ", Audio::Nama::width($track->width),
+				"Track $name set to ", Audio::Nama::width($track->width),
 				qq(, but JACK source "$id" is ), Audio::Nama::width($width), '.');
 		}
 		elsif( $type eq 'jack_ports_list' ){
@@ -686,7 +686,7 @@ sub set_rw {
 	#my $already = $track->rw eq $setting ? " already" : "";
 	$track->set(rw => $setting);
 	my $status = $track->rec_status();
-	Audio::Nama::pager($track->name, " set to $setting", 
+	Audio::Nama::pager("Track ",$track->name, " set to $setting", 
 		($status ne $setting ? ", but current status is $status" : ""));
 
 }
@@ -1319,8 +1319,6 @@ our @ISA = 'Audio::Nama::SlaveTrack';
 package Audio::Nama;
 use Modern::Perl;
 
-# usual track
-
 sub add_track {
 
 	logsub("&add_track");
